window.Gleam.initSearch([{"doc":"gleam_httpc","title":"gleam_httpc","content":"# httpc\n&lt;a href=&quot;https://github.com/gleam-lang/httpc/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/gleam-lang/httpc&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt;\n&lt;a href=&quot;https://discord.gg/Fm8Pwmy&quot;&gt;&lt;img src=&quot;https://img.shields.io/discord/768594524158427167?color=blue&quot; alt=&quot;Discord chat&quot;&gt;&lt;/a&gt;\n![CI](https://github.com/gleam-lang/httpc/workflows/test/badge.svg?branch=main)\n\nBindings to Erlang&#39;s built in HTTP client, `httpc`.\n\n```gleam\nimport gleam/httpc\nimport gleam/http.{Get}\nimport gleam/http/request\nimport gleam/http/response\nimport gleeunit/should\n\npub fn main() {\n  // Prepare a HTTP request record\n  let request = request.new()\n    |&gt; request.set_method(Get)\n    |&gt; request.set_host(&quot;test-api.service.hmrc.gov.uk&quot;)\n    |&gt; request.set_path(&quot;/hello/world&quot;)\n    |&gt; request.prepend_header(&quot;accept&quot;, &quot;application/vnd.hmrc.1.0+json&quot;)\n\n  // Send the HTTP request to the server\n  try resp = httpc.send(req)\n\n  // We get a response record back\n  resp.status\n  |&gt; should.equal(200)\n\n  resp\n  |&gt; response.get_header(&quot;content-type&quot;)\n  |&gt; should.equal(Ok(&quot;application/json&quot;))\n\n  resp.body\n  |&gt; should.equal(&quot;{\\&quot;message\\&quot;:\\&quot;Hello World\\&quot;}&quot;)\n\n  Ok(resp)\n}\n```\n\n## Installation\n\n```shell\ngleam add gleam_httpc\n```\n\n## Use with Erlang/OTP versions older than 26.0\n\nOlder versions of HTTPC do not verify TLS connections by default, so with them\nyour connection may not be secure when using this library. Consider upgrading to\na newer version of Erlang/OTP, or using a different HTTP client such as\n[hackney](https://github.com/gleam-lang/hackney).\n","url":"index.html"},{"doc":"gleam/httpc","title":"send","content":"pub fn send(\n  req: Request(String),\n) -&gt; Result(Response(String), Dynamic)\n\nSynonyms:\ngleam/httpc.send\ngleam/httpc send","url":"gleam/httpc.html#send"},{"doc":"gleam/httpc","title":"send_bits","content":"pub fn send_bits(\n  req: Request(BitArray),\n) -&gt; Result(Response(BitArray), Dynamic)\n\nSynonyms:\ngleam/httpc.send_bits\ngleam/httpc send_bits","url":"gleam/httpc.html#send_bits"},{"doc":"gleam/httpc","title":"gleam/httpc","content":"","url":"gleam/httpc.html"}]);